@@ -311,22 +311,22 @@ class Bootstrap:
         the second the target class performance (empty if not requested)
         """
         if targs.shape[1] == 1:
-            rounding_value = 2
-            h0_acc  = accuracy_score(targs, h0_preds)
-            h0_f1   = f1_score(targs, h0_preds, average='macro')
-            h0_prec = precision_score(targs, h0_preds, average='macro')
-            h0_rec  = recall_score(targs, h0_preds, average='macro')
-            h1_acc  = accuracy_score(targs, h1_preds)
-            h1_f1   = f1_score(targs, h1_preds, average='macro')
-            h1_prec = precision_score(targs, h1_preds, average='macro')
-            h1_rec  = recall_score(targs, h1_preds, average='macro')
+            rounding_value = 4
+            h0_acc    = round(accuracy_score(targs, h0_preds), rounding_value)
+            h0_f1     = round(f1_score(targs, h0_preds, average='macro'), rounding_value)
+            h0_prec   = round(precision_score(targs, h0_preds, average='macro'), rounding_value)
+            h0_rec    = round(recall_score(targs, h0_preds, average='macro'), rounding_value)
+            h1_acc    = round(accuracy_score(targs, h1_preds), rounding_value)
+            h1_f1     = round(f1_score(targs, h1_preds, average='macro'), rounding_value)
+            h1_prec   = round(precision_score(targs, h1_preds, average='macro'), rounding_value)
+            h1_rec    = round(recall_score(targs, h1_preds, average='macro'), rounding_value)
+            diff_acc  = round(h1_acc  - h0_acc, rounding_value)
+            diff_f1   = round(h1_f1   - h0_f1, rounding_value)
+            diff_prec = round(h1_prec - h0_prec, rounding_value)
+            diff_rec  = round(h1_rec  - h0_rec, rounding_value)
             # h0_conf_matrix = confusion_matrix(targs, h0_preds)
             # h1_conf_matrix = confusion_matrix(targs, h1_preds)
             # print(h0_conf_matrix, "\n", h1_conf_matrix)
-            diff_acc  = h1_acc  - h0_acc
-            diff_f1   = h1_f1   - h0_f1
-            diff_prec = h1_prec - h0_prec
-            diff_rec  = h1_rec  - h0_rec
             df_tot = pd.DataFrame({ 'f1':    [h0_f1,       h1_f1],       'd_f1':    ['',  diff_f1],       's_f1':    ['', ''],
                                     'acc':   [h0_acc,      h1_acc],      'd_acc':   ['',  diff_acc],      's_acc':   ['', ''],
                                     'prec':  [h0_prec,     h1_prec],     'd_prec':  ['',  diff_prec],     's_prec':  ['', ''],
@@ -355,12 +355,12 @@ class Bootstrap:
                 assert targetclass in np.unique(targs), 'targetclass must belong to the classes\' set'
                 h0_vals = precision_recall_fscore_support(targs, h0_preds)
                 h1_vals = precision_recall_fscore_support(targs, h1_preds)
-                h0_tgt_prec   = round(h0_vals[0][targetclass] * 100, rounding_value)
-                h0_tgt_rec    = round(h0_vals[1][targetclass] * 100, rounding_value)
-                h0_tgt_f1     = round(h0_vals[2][targetclass] * 100, rounding_value)
-                h1_tgt_prec   = round(h1_vals[0][targetclass] * 100, rounding_value)
-                h1_tgt_rec    = round(h1_vals[1][targetclass] * 100, rounding_value)
-                h1_tgt_f1     = round(h1_vals[2][targetclass] * 100, rounding_value)
+                h0_tgt_prec   = round(h0_vals[0][targetclass], rounding_value)
+                h0_tgt_rec    = round(h0_vals[1][targetclass], rounding_value)
+                h0_tgt_f1     = round(h0_vals[2][targetclass], rounding_value)
+                h1_tgt_prec   = round(h1_vals[0][targetclass], rounding_value)
+                h1_tgt_rec    = round(h1_vals[1][targetclass], rounding_value)
+                h1_tgt_f1     = round(h1_vals[2][targetclass], rounding_value)
                 diff_tgt_f1   = round(h1_tgt_f1   - h0_tgt_f1,   rounding_value)
                 diff_tgt_prec = round(h1_tgt_prec - h0_tgt_prec, rounding_value)
                 diff_tgt_rec  = round(h1_tgt_rec  - h0_tgt_rec,  rounding_value)
@@ -623,10 +623,10 @@ class Bootstrap:
                     df_tot_cond['std_f1']      = [round(np.std(h0_f1_all), 2), round(np.std(h1_f1_all), 2)]
                 else:
                     df_tot_cond['std_jsd']     = [round(np.std(h0_jsd_all), 2), round(np.std(h1_jsd_all), 2)]
-                if h0_cond not in df_tot.index:
-                    df_tot = df_tot.append(df_tot_cond.iloc[0, :])
-                if h1_cond not in df_tot.index:
-                    df_tot = df_tot.append(df_tot_cond.iloc[1, :])
+                if h0_cond not in df_tot.columns:
+                    df_tot = pd.concat([df_tot, df_tot_cond.iloc[0, :]], axis=1)
+                if h1_cond not in df_tot.columns:
+                    df_tot = pd.concat([df_tot, df_tot_cond.iloc[1, :]], axis=1)
 
                 if targetclass is not None:
                     with warnings.catch_warnings():
@@ -634,18 +634,20 @@ class Bootstrap:
                         df_tgt_cond['mean_epochs'] = [round(np.mean(self.data[h0_cond]['epochs']), 2), round(np.mean(self.data[h0_cond]['h1'][h1_cond]['epochs']), 2)]
                     if self.data[h0_cond]['targs'][0].shape[1] == 1:
                         df_tgt_cond['std_tf1']  = [round(np.std(h0_f1tgt_all), 2), round(np.std(h1_f1tgt_all), 2)]
-                    if h0_cond not in df_tgt.index:
-                        df_tgt = df_tgt.append(df_tgt_cond.iloc[0, :])
-                    if h1_cond not in df_tgt.index:
-                        df_tgt = df_tgt.append(df_tgt_cond.iloc[1, :])
+                    if h0_cond not in df_tgt.columns:
+                        df_tgt = pd.concat([df_tgt, df_tgt_cond.iloc[0, :]], axis=1)
+                    if h1_cond not in df_tgt.columns:
+                        df_tgt = pd.concat([df_tgt, df_tgt_cond.iloc[1, :]], axis=1)
 
         if self.data[list(self.data.keys())[0]]['targs'][0].shape[1] == 1:
-            df_tot = df_tot['mean_epochs f1 d_f1 s_f1 std_f1 acc d_acc s_acc prec d_prec s_prec rec d_rec s_rec'.split()].round(4)
+            df_tot = df_tot.T['mean_epochs f1 d_f1 s_f1 std_f1 acc d_acc s_acc prec d_prec s_prec rec d_rec s_rec'.split()].round(4)
         else:
-            df_tot = df_tot['mean_epochs jsd d_jsd s_jsd std_jsd ce d_ce s_ce sim d_sim s_sim cor d_cor s_cor'.split()].round(4)
+            df_tot = df_tot.T['mean_epochs jsd d_jsd s_jsd std_jsd ce d_ce s_ce sim d_sim s_sim cor d_cor s_cor'.split()].round(4)
         if targetclass is not None:
             if self.data[list(self.data.keys())[0]]['targs'][0].shape[1] == 1:
-                df_tgt = df_tgt['mean_epochs tf1 d_tf1 s_tf1 std_tf1 tprec d_tprec s_tprec trec d_trec s_trec'.split()].round(4)
+                df_tgt = df_tgt.T['mean_epochs tf1 d_tf1 s_tf1 std_tf1 tprec d_tprec s_tprec trec d_trec s_trec'.split()].round(4)
+            else:
+                df_tgt = df_tgt.T
             df_both = pd.concat([df_tot, df_tgt.iloc[:, 1:]], axis=1)
             print(df_both.to_string())
             if self.savetsv:
